@@ -26,6 +26,8 @@
 #include "utils.h"
 #include "gearman_utils.h"
 
+#include <worker_dummy_functions.c>
+
 gearman_client_st client;
 gearman_client_st client_dup;
 int results_sent = 0;
@@ -270,7 +272,9 @@ int send_result() {
     else if(mod_gm_opt->message == NULL) {
         /* get all lines from stdin */
         mod_gm_opt->message = gm_malloc(GM_BUFFERSIZE);
+        alarm(mod_gm_opt->timeout);
         read_filepointer(&mod_gm_opt->message, stdin);
+        alarm(0);
     }
     return(submit_result());
 }
